@@ -69,26 +69,32 @@ class InterfaceMQTT:
         self.__logger.info('Connected with mqtt broker')
 
         sensor_topic_head = "homeassistant/sensor/" + self.__device_id
+        number_topic_head = "homeassistant/number/" + self.__device_id
+        select_topic_head = "homeassistant/select/" + self.__device_id
         switch_topic_head = "homeassistant/switch/" + self.__device_id
 
         # send last will and testament
         available_topic = switch_topic_head + "/available"
         client.publish(available_topic, "online", qos=0, retain=True)
 
-        # state_topic for all picframe sensors
-        state_topic = sensor_topic_head + "/state"
-
         ## sensors
         self.__setup_sensor(client, sensor_topic_head, "date_from", "mdi:calendar-arrow-left", available_topic)
         self.__setup_sensor(client, sensor_topic_head, "date_to", "mdi:calendar-arrow-right", available_topic)
-        self.__setup_sensor(client, sensor_topic_head, "time_delay", "mdi:image-plus", available_topic)
-        self.__setup_sensor(client, sensor_topic_head, "brightness", "mdi:brightness-6", available_topic)
-        self.__setup_sensor(client, sensor_topic_head, "fade_time", "mdi:image-size-select-large", available_topic)
         self.__setup_sensor(client, sensor_topic_head, "location_filter", "mdi:map-search", available_topic)
         self.__setup_sensor(client, sensor_topic_head, "tags_filter", "mdi:image-search", available_topic)
         self.__setup_sensor(client, sensor_topic_head, "image_counter", "mdi:camera-burst", available_topic)
         self.__setup_sensor(client, sensor_topic_head, "image", "mdi:file-image", available_topic, has_attributes=True)
-        self.__setup_sensor(client, sensor_topic_head, "directory", "mdi:folder-multiple-image", available_topic, has_attributes=True)
+        
+
+        ## numbers
+        self.__setup_number(client, number_topic_head, "brightness", 0.0, 1.0, 0.1, "mdi:brightness-6", available_topic)
+        self.__setup_number(client, number_topic_head, "time_delay", 1, 400, 1, "mdi:image-plus", available_topic)
+        self.__setup_number(client, number_topic_head, "fade_time", 1, 50, 1,"mdi:image-size-select-large", available_topic)
+
+        ## selects
+        _, dir_list = self.__controller.get_directory_list()
+        dir_list.sort()
+        self.__setup_select(client, select_topic_head, "directory", dir_list, "mdi:folder-multiple-image", available_topic)
 
         ## switches
         self.__setup_switch(client, switch_topic_head, "_text_refresh", "mdi:refresh", available_topic)
@@ -142,6 +148,43 @@ class InterfaceMQTT:
                                      "dev":{"ids":[self.__device_id]}})
         client.publish(config_topic, config_payload, qos=0, retain=True)
         client.subscribe(self.__device_id + "/" + topic, qos=0)
+    
+    def __setup_number(self, client, number_topic_head, topic, min, max, step, icon, available_topic):
+        config_topic = number_topic_head + "_" + topic + "/config"
+        command_topic = self.__device_id + "/" + topic
+        state_topic = "homeassistant/sensor/" + self.__device_id + "/state"
+        name = self.__device_id + "_" + topic
+        config_payload = json.dumps({"name": name,
+                                    "min": min,
+                                    "max": max,
+                                    "step": step,
+                                    "icon": icon,
+                                    "state_topic": state_topic,
+                                    "command_topic": command_topic,
+                                    "value_template": "{{ value_json." + topic + "}}",
+                                    "avty_t": available_topic,
+                                    "uniq_id": name,
+                                    "dev":{"ids":[self.__device_id]}})
+        client.publish(config_topic, config_payload, qos=0, retain=True)
+        client.subscribe(command_topic, qos=0)
+
+    def __setup_select(self, client, select_topic_head, topic, options, icon, available_topic):
+        config_topic = select_topic_head + "_" + topic + "/config"
+        command_topic = self.__device_id + "/" + topic
+        state_topic = "homeassistant/sensor/" + self.__device_id + "/state"
+        name = self.__device_id + "_" + topic
+        
+        config_payload = json.dumps({"name": name,
+                                    "icon": icon,
+                                    "options": options,
+                                    "state_topic": state_topic,
+                                    "command_topic": command_topic,
+                                    "value_template": "{{ value_json." + topic + "}}",
+                                    "avty_t": available_topic,
+                                    "uniq_id": name,
+                                    "dev":{"ids":[self.__device_id]}})
+        client.publish(config_topic, config_payload, qos=0, retain=True)
+        client.subscribe(command_topic, qos=0)
 
     def __setup_switch(self, client, switch_topic_head, topic, icon,
                        available_topic, is_on=False):
@@ -328,44 +371,50 @@ class InterfaceMQTT:
             self.__controller.stop()
 
     def publish_state(self, image, image_attr):
-        topic_head =  "homeassistant/sensor/" + self.__device_id
+        sensor_topic_head =  "homeassistant/sensor/" + self.__device_id
         switch_topic_head = "homeassistant/switch/" + self.__device_id
-        state_topic = topic_head + "/state"
-        state_payload = {}
+        select_topic_head = "homeassistant/select/" + self.__device_id
+        sensor_state_topic = sensor_topic_head + "/state"
+
+        sensor_state_payload = {}
+
+        ## sensor  
         # directory sensor
         actual_dir, dir_list = self.__controller.get_directory_list()
-        state_payload["directory"] = actual_dir
-        dir_attr = {}
-        dir_attr['directories'] = dir_list
+        sensor_state_payload["directory"] = actual_dir
         # image counter sensor
-        state_payload["image_counter"] = str(self.__controller.get_number_of_files())
+        sensor_state_payload["image_counter"] = str(self.__controller.get_number_of_files())
         # image sensor
         _, tail = os.path.split(image)
-        state_payload["image"] = tail
+        sensor_state_payload["image"] = tail
         # date_from
-        state_payload["date_from"] = int(self.__controller.date_from)
+        sensor_state_payload["date_from"] = int(self.__controller.date_from)
         # date_to
-        state_payload["date_to"] = int(self.__controller.date_to)
-        # time_delay
-        state_payload["time_delay"] = self.__controller.time_delay
-        # fade_time
-        state_payload["fade_time"] = self.__controller.fade_time
-        # brightness
-        state_payload["brightness"] = self.__controller.brightness
+        sensor_state_payload["date_to"] = int(self.__controller.date_to)
         # location_filter
-        state_payload["location_filter"] = self.__controller.location_filter
+        sensor_state_payload["location_filter"] = self.__controller.location_filter
         # tags_filter
-        state_payload["tags_filter"] = self.__controller.tags_filter
+        sensor_state_payload["tags_filter"] = self.__controller.tags_filter
+
+        ## number state
+        # time_delay
+        sensor_state_payload["time_delay"] = self.__controller.time_delay
+        # fade_time
+        sensor_state_payload["fade_time"] = self.__controller.fade_time
+        # brightness
+        sensor_state_payload["brightness"] = self.__controller.brightness
 
         # send last will and testament
         available_topic = switch_topic_head + "/available"
         self.__client.publish(available_topic, "online", qos=0, retain=True)
 
         #pulish sensors
-        attributes_topic = topic_head + "_image/attributes"
+        attributes_topic = sensor_topic_head + "_image/attributes"
         self.__logger.debug("Send image attributes: %s", image_attr)
         self.__client.publish(attributes_topic, json.dumps(image_attr), qos=0, retain=False)
-        attributes_topic = topic_head + "_directory/attributes"
-        self.__client.publish(attributes_topic, json.dumps(dir_attr), qos=0, retain=False)
-        self.__logger.info("Send state: %s", state_payload)
-        self.__client.publish(state_topic, json.dumps(state_payload), qos=0, retain=False)
+        dir_list.sort()
+        self.__setup_select(self.__client, select_topic_head, "directory", dir_list, "mdi:folder-multiple-image", available_topic)
+
+        self.__logger.info("Send sensor state: %s", sensor_state_payload)
+        self.__client.publish(sensor_state_topic, json.dumps(sensor_state_payload), qos=0, retain=False)
+
